<p align="center">
  <a href="https://github.com/cloudsen12/maskay-puyu"><img src="https://www.latercera.com/resizer/V5aqG9i9lnIZsWyq5mDUSVg5-RQ=/900x600/smart/arc-anglerfish-arc2-prod-copesa.s3.amazonaws.com/public/V4TSQHKN2RD3DBB2YSCKGSDVMU.jpg" alt="llama"></a>
</p>
<p align="center">
    <em>A Python package about llamas</em>
</p>
<p align="center">
<a href='https://pypi.python.org/pypi/maskay'>
    <img src='https://img.shields.io/pypi/v/maskay.svg' alt='PyPI' />
</a>
<a href='https://anaconda.org/conda-forge/maskay'>
    <img src='https://img.shields.io/conda/vn/conda-forge/maskay.svg' alt='conda-forge' />
</a>
<a href='https://maskay.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/maskay/badge/?version=latest' alt='Documentation Status' />
</a>
<a href="https://github.com/cloudsen12/maskay-puyu/actions/workflows/tests.yml" target="_blank">
    <img src="https://github.com/cloudsen12/maskay-puyu/actions/workflows/tests.yml/badge.svg" alt="Tests">
</a>
<a href="https://opensource.org/licenses/Apache-2.0" target="_blank">
    <img src="https://img.shields.io/badge/License-Apache-blue.svg" alt="License">
</a>
<a href="https://twitter.com/csaybar" target="_blank">
    <img src="https://img.shields.io/twitter/follow/csaybar?style=social" alt="Twitter Cesar">
</a>
<a href="https://twitter.com/dmlmont" target="_blank">
    <img src="https://img.shields.io/twitter/follow/dmlmont?style=social" alt="Twitter David">
</a>
<a href="https://github.com/psf/black" target="_blank">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Black">
</a>
<a href="https://pycqa.github.io/isort/" target="_blank">
    <img src="https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336" alt="isort">
</a>
</p>

---

**GitHub**: [https://github.com/cloudsen12/maskay-puyu](https://github.com/cloudsen12/maskay-puyu)

**Documentation**: [https://maskay.readthedocs.io/](https://maskay.readthedocs.io/)

**PyPI**: [https://pypi.org/project/maskay/](https://pypi.org/project/maskay/)

**Conda-forge**: [https://anaconda.org/conda-forge/maskay](https://anaconda.org/conda-forge/maskay)

---


# Overview

A Python package about llamas
